@@ -9,7 +9,7 @@ require Exporter;
 use Data::Dumper;
 
 use vars qw(@ISA $VERSION @EXPORT_OK);
-$VERSION = '1.41';
+$VERSION = '1.42';
 @ISA = qw(DynaLoader Exporter);
 
 # Only return the exception key for registered RFCs
@@ -101,7 +101,10 @@ my $VALID =  {
     ABAP_DEBUG => 1,
     USE_SAPGUI => 1,
     TYPE => 1,
-    LINTTYP => 1
+    LINTTYP => 1,
+    GETSSO2 => 1,
+    MYSAPSSO2 => 1,
+    X509CERT => 1,
   };
 
 
@@ -171,8 +174,8 @@ sub new {
 	INTERFACES => {},
         LINTTYP => ( ( join(" ", map { sprintf "%#02x", $_ } unpack("C*",pack("L",0x12345678))) eq "0x78 0x56 0x34 0x12") ? "LIT" : "BIG" ),
 	CLIENT => "000",
-	USER   => "SAPCPIC",
-	PASSWD => "ADMIN",
+	#USER   => "SAPCPIC",
+	#PASSWD => "ADMIN",
 	LANG   => "EN",
 	LCHECK   => "0",
 	TRFC   => 0,
@@ -337,7 +340,7 @@ sub login_string {
   #$self->{PASSWD} = uc( $self->{PASSWD} );
 
 # create the login string but only return valid parameters
-  map { $connect.= $_ . "=" . $self->{$_} . " " } keys %{$self};
+  map { unless (/LINTTYP|HANDLE|TRFC_COMMIT|RETURN|SYSINFO|TRFC_ROLLBACK|TRFC_CONFIRM|TRFC_CHECK/){$connect.= $_ . "=" . $self->{$_} . " "} } keys %{$self};
 
   return $connect;
 }
@@ -817,6 +820,24 @@ sub callrfc {
 }
 
 
+# Get the logon ticket
+sub getTicket {
+  my $self = shift;
+
+  die "SAP Connection Not Open for Ticket retrieval "
+     if ! is_connected( $self );
+
+  my $result = MyGetTicket($self->{'HANDLE'});
+  
+  if ( $result->{'__RETURN_CODE__'} ne "0" ){
+      $self->{'ERROR'} = $result->{'__RETURN_CODE__'};
+      die "RFC call failed: ".$result->{'__RETURN_CODE__'};
+  } else {
+	    return $result->{'TICKET'};
+  }
+}
+
+
 # convert internal data types to externals
 sub intoext{
     my $parm = shift;
@@ -980,6 +1001,32 @@ Please note that USER and PASSWD are now case sensitive - this change has the po
   contents, and then cleans the libraries storage space again.
 
 
+=head2 getTicket()
+
+	This is for using SAP Logon Tickets, generated by your R/3 system.
+
+  retrieve the requested ticket:
+  $rfc = new SAP::Rfc(
+		      ASHOST   => 'myhost',
+		      USER     => 'ME',
+		      PASSWD   => 'secret',
+		      GETSSO2   => 1,
+		      LANG     => 'EN',
+		      CLIENT   => '200',
+		      SYSNR    => '00',
+		      TRACE    => '1' );
+  my $ticket = $rfc->getTicket();
+
+  The ticket can then be used to do logins like so:
+  $rfc = new SAP::Rfc(
+		      ASHOST   => 'myhost',
+		      MYSAPSSO2   => $ticket,
+		      LANG     => 'EN',
+		      CLIENT   => '200',
+		      SYSNR    => '00',
+		      TRACE    => '1' );
+
+
 =head2 close()
 
   $rfc->close();
